import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { scaleSqrt, max } from 'd3';
import { useWorldAtlas } from './useWorldAtlas';
import { useCities } from './useCities';
import { Marks } from './Marks'


const width = 960;
const height = 500;
const margin = {top: 20, right: 30, bottom: 65, left: 90};
const xAxisLabelOffset = 50;
const yAxisLabelOffset = 40;

const App = () => {
  const data = useWorldAtlas();
  const cities = useCities() || [0];
  const maxRadius = 15
  const sizeValue = d => d.population;
  const sizeScale = scaleSqrt()
  									.domain([0, max(cities, sizeValue)])
  									.range([0, maxRadius])
	console.log(cities)
  if (!data || !cities) { 
    return <pre>Loading...</pre>;
  }
  console.log(max(cities, (d) => +d.population))
  return (
    <svg width={width} height={height}>
      	<Marks wordlAtlas={data} cities={cities} sizeScale={sizeScale} sizeValue={sizeValue}/>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);

// To compute the arcs manually (without d3.pie):
// data.map((d, i) => (
//   <path
//     fill={d['RGB hex value']}
//     d={pieArc({
//       startAngle: (i / data.length) * 2 * Math.PI,
//       endAngle: ((i + 1) / data.length) * 2 * Math.PI
//     })}
//   />
// ))
